@@ -29,7 +29,9 @@
 #include <glib.h>
 #include <gio/gio.h>
 
+#ifdef HAVE_GCONF
 #include <gconf/gconf-client.h>
+#endif
 
 #include "gsm-autostart-app.h"
 #include "gsm-util.h"
@@ -43,7 +45,9 @@ enum {
         GSM_CONDITION_NONE           = 0,
         GSM_CONDITION_IF_EXISTS      = 1,
         GSM_CONDITION_UNLESS_EXISTS  = 2,
+#ifdef HAVE_GCONF
         GSM_CONDITION_GNOME          = 3,
+#endif
         GSM_CONDITION_GSETTINGS      = 4,
         GSM_CONDITION_IF_SESSION     = 5,
         GSM_CONDITION_UNLESS_SESSION = 6,
@@ -171,8 +175,10 @@ parse_condition_string (const char *condition_string,
                 kind = GSM_CONDITION_IF_EXISTS;
         } else if (!g_ascii_strncasecmp (condition_string, "unless-exists", len) && key) {
                 kind = GSM_CONDITION_UNLESS_EXISTS;
+#ifdef HAVE_GCONF
         } else if (!g_ascii_strncasecmp (condition_string, "GNOME", len)) {
                 kind = GSM_CONDITION_GNOME;
+#endif
         } else if (!g_ascii_strncasecmp (condition_string, "GSettings", len)) {
                 kind = GSM_CONDITION_GSETTINGS;
         } else if (!g_ascii_strncasecmp (condition_string, "GNOME3", len)) {
@@ -267,6 +273,7 @@ unless_exists_condition_cb (GFileMonitor     *monitor,
         }
 }
 
+#ifdef HAVE_GCONF
 static void
 gconf_condition_cb (GConfClient *client,
                     guint        cnxn_id,
@@ -298,6 +305,7 @@ gconf_condition_cb (GConfClient *client,
                 g_signal_emit (app, signals[CONDITION_CHANGED], 0, condition);
         }
 }
+#endif
 
 static void
 gsettings_condition_cb (GSettings  *settings,
@@ -458,6 +466,7 @@ setup_condition_monitor (GsmAutostartApp *app)
                 g_file_monitor_cancel (app->priv->condition_monitor);
         }
 
+#ifdef HAVE_GCONF
         if (app->priv->condition_notify_id > 0) {
                 GConfClient *client;
                 client = gconf_client_get_default ();
@@ -465,6 +474,7 @@ setup_condition_monitor (GsmAutostartApp *app)
                                             app->priv->condition_notify_id);
                 app->priv->condition_notify_id = 0;
         }
+#endif
 
         if (app->priv->condition_string == NULL) {
                 return;
@@ -520,6 +530,7 @@ setup_condition_monitor (GsmAutostartApp *app)
 
                 g_object_unref (file);
                 g_free (file_path);
+#ifdef HAVE_GCONF
         } else if (kind == GSM_CONDITION_GNOME) {
                 GConfClient *client;
                 char        *dir;
@@ -541,6 +552,7 @@ setup_condition_monitor (GsmAutostartApp *app)
                                                                           gconf_condition_cb,
                                                                           app, NULL, NULL);
                 g_object_unref (client);
+#endif
         } else if (kind == GSM_CONDITION_GSETTINGS) {
                 disabled = !setup_gsettings_condition_monitor (app, key);
         } else if (kind == GSM_CONDITION_IF_SESSION) {
@@ -856,12 +868,14 @@ is_conditionally_disabled (GsmApp *app)
                 file_path = g_build_filename (g_get_user_config_dir (), key, NULL);
                 disabled = g_file_test (file_path, G_FILE_TEST_EXISTS);
                 g_free (file_path);
+#ifdef HAVE_GCONF
         } else if (kind == GSM_CONDITION_GNOME) {
                 GConfClient *client;
                 client = gconf_client_get_default ();
                 g_assert (GCONF_IS_CLIENT (client));
                 disabled = !gconf_client_get_bool (client, key, NULL);
                 g_object_unref (client);
+#endif
         } else if (kind == GSM_CONDITION_GSETTINGS &&
                    priv->condition_settings != NULL) {
                 char **elems;
